// ---------------------------------------------------------------------------
// pack_and_back.cs -- Version 2.4 -- February 11, 2000
// by Lorne Laliberte (writer@planetstarsiege.com)
//
// Automatically switch back to your previous weapon when you complete repairs
//
// http://www.writerscripts.com
// ---------------------------------------------------------------------------

include("writer\\version.cs");
version("writer\\pack_and_back.cs", "2.4", "Lorne Laliberte", "Feb 11, 2000");

include("writer\\event.cs");
include("writer\\inventory.cs");
include("writer\\item_events.cs");

// Switch back to previous weapon if the repair pack is dropped
// when the repair gun is mounted
function PackAndBack::onUnmount(%weapon)
{
    if((%weapon == $Inv::Repair_Gun) || (%weapon == $Inv::Engineer_Repair_Gun))
    {
        if( ($OldWeapon == "") || ($OldWeapon == -1) )
        {
            nextWeapon();
        }
        else
        {
            if(getItemCount($Inv::Name[$OldWeapon]))
                useType($OldWeapon);
            else
                nextWeapon();
        }
    }
}

// Re-select the previously selected weapon when a repair pack is turned off
function PackAndBack::onUse(%itemtype, %itemname)
{
    %pack = getMountedItem(1);
    %weapon = getMountedItem(0);

  	if((%itemtype == $Inv::Repair_Pack) || (%itemtype == $Inv::Engineer_Repair_Pack))
  	{
        // Repair packs replace the currently selected weapon
        // with the RepairGun, and are turned off by selecting
        // a different weapon

  	    if((%weapon == $Inv::Repair_Gun) || (%weapon == $Inv::Engineer_Repair_Gun))
  	    {
            // Do we know what weapon was selected before?
            if( ($OldWeapon == "") || ($OldWeapon == -1) )
            {
                // No -- switch to next available weapon
                nextWeapon();
            }
            else
            {
                // Yes -- switch back to previously selected weapon
                useType($OldWeapon);
            }

            // We need to cancel the useItem() call for the repair pack
            // or the useItem call for $OldWeapon won't get through.
            // By returning "mute" we tell use() not to issue the useItem() call.

            return mute;
  	    }
  	    else
  	    {
            // Switch to the repair pack and remember which weapon
            // was selected so we can switch back to it later
      		$OldWeapon = %weapon;
  	    }
  	}
  	return;
}

function pack_and_back::init()
{
    needs("writer\\pack_and_back.cs", "writer\\event.cs 2.7",
                                      "writer\\inventory.cs 3.3",
                                      "writer\\item_events.cs 2.12");

    Event::Attach(eventUnmount, PackAndBack::onUnmount);
    Event::Attach(eventUse, PackAndBack::onUse);
}
Event::Attach(writerInit, "pack_and_back::init();");

if(!$UsingWriterLoader) pack_and_back::init();
